import uvicorn
from fastapi import FastAPI
from app.api.todos import router as todos_router
from app.api.health import router as health_router
from app.database.database import Base, engine

# Create the database tables
Base.metadata.create_all(bind=engine)

# Create FastAPI app
app = FastAPI(
    title="Simple Todo API",
    description="A simple API for managing todos",
    version="0.1.0"
)

# Include routers
app.include_router(todos_router, prefix="/todos", tags=["todos"])
app.include_router(health_router, tags=["health"])

if __name__ == "__main__":
    uvicorn.run("main:app", host="0.0.0.0", port=8000, reload=True)